Module dispatch
Source - noop
- test
- SetDispatchError
- Error returned when attempting to set a dispatcher that has already been set.
- Event
- Events that can be emitted through the dispatcher.
- Dispatch
- Trait for event dispatchers that handle precept events and random number generation.
- choose
- Choose a random value from a slice of options using the dispatcher
- dispatcher
- Returns a reference to the dispatcher.
- emit
- Emit an event using the dispatcher
- get_random
- Generate a random u64 using the dispatcher
- set_dispatcher
- Set the DISPATCHER to the provided dispatcher instance. This function will
fail if called multiple times.